@@ -152,7 +152,7 @@ Hello.
     """''',
             docformatter.format_docstring(
                 '    ',
-                docstring = '''"""Foo bar
+                docstring='''"""Foo bar
         bing bang.
 
         >>> tests = DocTestFinder().find(_TestClass)
@@ -332,6 +332,24 @@ Hello.
     """
 '''.strip(), summary_wrap_length=79))
 
+    def test_format_docstring_should_leave_list_alone(self):
+        docstring = '''"""
+    one
+    two
+    three
+    four
+    five
+    six
+    seven
+    eight
+    nine
+    ten
+    eleven
+    """'''
+        self.assertEqual(
+            docstring,
+            docformatter.format_docstring('    ', docstring))
+
     def test_format_code(self):
         self.assertEqual(
             '''\
@@ -806,31 +824,13 @@ Try this and this and this and this and this and this and this at
     email : string
 '''))
 
-    def test_split_summary_and_description_with_column_of_items(self):
-        text = """
-        one
-        two
-        three
-        four
-        five
-        six
-        seven
-        eight
-        nine
-        ten
-        eleven
-        """
-        self.assertEqual(
-            ('', text),
-            docformatter.split_summary_and_description(text))
-
     def test_split_summary_and_description_with_abbreviation(self):
-        for text in  ['Test e.g. now'
-                      'Test i.e. now',
-                      'Test Dr. now',
-                      'Test Mr. now',
-                      'Test Mrs. now',
-                      'Test Ms. now']:
+        for text in ['Test e.g. now'
+                     'Test i.e. now',
+                     'Test Dr. now',
+                     'Test Mr. now',
+                     'Test Mrs. now',
+                     'Test Ms. now']:
             self.assertEqual(
                 (text, ''),
                 docformatter.split_summary_and_description(text))
@@ -904,17 +904,17 @@ Try this and this and this and this and this and this and this at
         self.assertEqual(
             ('This is a sentence.', ' More stuff. And more stuff.   .!@#$%'),
             docformatter.split_first_sentence(
-            'This is a sentence. More stuff. And more stuff.   .!@#$%'))
+                'This is a sentence. More stuff. And more stuff.   .!@#$%'))
 
         self.assertEqual(
             ('This e.g. sentence.', ' More stuff. And more stuff.   .!@#$%'),
             docformatter.split_first_sentence(
-            'This e.g. sentence. More stuff. And more stuff.   .!@#$%'))
+                'This e.g. sentence. More stuff. And more stuff.   .!@#$%'))
 
         self.assertEqual(
             ('This is the first:', '\none\ntwo'),
             docformatter.split_first_sentence(
-            'This is the first:\none\ntwo'))
+                'This is the first:\none\ntwo'))
 
 
 class TestSystem(unittest.TestCase):
@@ -992,9 +992,7 @@ def foo():
     Hello world
     """
 ''') as filename:
-            import subprocess
-            process = subprocess.Popen(['./docformatter', filename],
-                                       stdout=subprocess.PIPE)
+            process = run_docformatter([filename])
             self.assertEqual('''\
 @@ -1,4 +1,2 @@
  def foo():
@@ -1011,11 +1009,8 @@ def foo():
     Hello world this is a summary that will get wrapped
     """
 ''') as filename:
-            import subprocess
-            process = subprocess.Popen(['./docformatter',
-                                        '--wrap-summaries=40',
-                                        filename],
-                                       stdout=subprocess.PIPE)
+            process = run_docformatter(['--wrap-summaries=40',
+                                        filename])
             self.assertEqual('''\
 @@ -1,4 +1,3 @@
  def foo():
@@ -1036,13 +1031,11 @@ def foo():
 
     """
 ''') as filename:
-            import subprocess
-            process = subprocess.Popen(['./docformatter',
+            process = run_docformatter(['--wrap-summaries=40',
                                         '--wrap-summaries=40',
                                         '--pre-summary-newline',
                                         '--no-blank',
-                                        filename],
-                                       stdout=subprocess.PIPE)
+                                        filename])
             self.assertEqual('''\
 @@ -1,7 +1,9 @@
  def foo():
@@ -1060,9 +1053,7 @@ def foo():
 ''', '\n'.join(process.communicate()[0].decode('utf-8').split('\n')[2:]))
 
     def test_no_arguments(self):
-        import subprocess
-        process = subprocess.Popen(['./docformatter'],
-                                   stderr=subprocess.PIPE)
+        process = run_docformatter([])
         self.assertIn('arguments',
                       process.communicate()[1].decode('utf-8'))
 
@@ -1117,5 +1108,25 @@ def temporary_directory(directory='.', prefix=''):
         shutil.rmtree(temp_directory)
 
 
+def run_docformatter(arguments):
+    """Run subprocess with same Python path as parent.
+
+    Return subprocess object.
+
+    This is necessary for testing under "./setup.py test" without installing
+    "untokenize".
+
+    """
+    import os
+    environ = os.environ.copy()
+    import sys
+    environ['PYTHONPATH'] = os.pathsep.join(sys.path)
+    import subprocess
+    return subprocess.Popen([sys.executable, './docformatter'] + arguments,
+                            stdout=subprocess.PIPE,
+                            stderr=subprocess.PIPE,
+                            env=environ)
+
+
 if __name__ == '__main__':
     unittest.main()
